@@ -1,4 +1,7 @@
-class ActorException(Exception):
+from rekuest.errors import RekuestError
+
+
+class ActorException(RekuestError):
     pass
 
 
