@@ -1,34 +1,37 @@
 from pydantic import BaseModel
 from rekuest.actors.base import Actor
 from rekuest.api.schema import LogLevelInput
-from rekuest.messages import Assignation
+from rekuest.messages import Assignation, Provision
 from koil import unkoil
 
 
 class AssignationHelper(BaseModel):
-    actor: Actor
     assignation: Assignation
 
     async def alog(self, level: LogLevelInput, message: str) -> None:
-        await self.actor.transport.log_to_assignation(
-            id=self.assignation.assignation, level=level, message=message
-        )
+        raise NotImplementedError()
 
     async def aprogress(self, progress: int) -> None:
-        await self.actor.transport.change_assignation(
-            id=self.assignation.assignation, progress=progress
-        )
+        raise NotImplementedError()
+
+    @property
+    def user(self) -> str:
+        return self.assignation.user
 
     class Config:
         arbitrary_types_allowed = True
 
 
 class ProvisionHelper(BaseModel):
-    actor: Actor
+    provision: Provision
 
     async def alog(self, level: LogLevelInput, message: str) -> None:
         raise NotImplementedError()
 
+    @property
+    def guardian(self) -> str:
+        return self.provision.guardian
+
 
 class ThreadedAssignationHelper(AssignationHelper):
     def progress(self, progress: int) -> None:
