@@ -5,7 +5,11 @@ from rekuest.api.schema import AssignationStatus, LogLevelInput
 from rekuest.messages import Assignation
 
 
-class ActorTransport(BaseModel):
+class BaseActorTransport(BaseModel):
+    pass
+
+
+class ActorTransport(BaseActorTransport):
 
     log_to_assignation: Callable[[str, LogLevelInput, str], Awaitable[None]]
     change_assignation: Callable[[Assignation, AssignationStatus, str], Awaitable[None]]
