@@ -34,16 +34,25 @@ logger = logging.getLogger(__name__)
 class BaseAgent(KoiledModel):
     """Agent
 
-    Agents are the governing entities in the arkitekt system. They are responsible for
-    spawning and managing the lifecycle of Actors and registering Templates with the help
-    of the DefinitionRegistry.
+    Agents are the governing entities for every app. They are responsible for
+    managing the lifecycle of the direct actors that are spawned from them through arkitekt.
+
+    Agents are nothing else than actors in the classic distributed actor model, but they are
+    always provided when the app starts and they do not provide functionality themselves but rather
+    manage the lifecycle of the actors that are spawned from them.
+
+    The actors that are spawned from them are called guardian actors and they are the ones that+
+    provide the functionality of the app. These actors can then in turn spawn other actors that
+    are not guardian actors. These actors are called non-guardian actors and their lifecycle is
+    managed by the guardian actors that spawned them. This allows for a hierarchical structure
+    of actors that can be spawned from the agents.
+
 
     """
 
     transport: AgentTransport
     definition_registry: Optional[DefinitionRegistry] = None
 
-    provisionProvisionMap: Dict[str, ProvisionFragment] = Field(default_factory=dict)
     provisionActorMap: Dict[str, Actor] = Field(default_factory=dict)
 
     rath: Optional[RekuestRath] = None
@@ -103,17 +112,18 @@ class BaseAgent(KoiledModel):
                 self._templateActorBuilderMap[arkitekt_template.id] = defined_actor
                 self._templateTemplatesMap[arkitekt_template.id] = arkitekt_template
 
-    async def aspawn_actor(self, message: Provision) -> Actor:
+    async def aspawn_actor(self, prov: Provision) -> Actor:
         """Spawns an Actor from a Provision"""
-        prov = await aget_provision(message.provision)
         try:
-            actor_builder = self._templateActorBuilderMap[prov.template.id]
+            actor_builder = self._templateActorBuilderMap[prov.template]
+            template = self._templateTemplatesMap[prov.template]
         except KeyError as e:
             raise ProvisionException("No Actor Builder found for template") from e
-        actor = actor_builder(provision=prov, transport=self.transport)
+        actor = actor_builder(
+            provision=prov, transport=self.transport, template=template
+        )
         await actor.arun()
-        self.provisionActorMap[prov.id] = actor
-        self.provisionProvisionMap[prov.id] = prov
+        self.provisionActorMap[prov.provision] = actor
         return actor
 
     async def astep(self):
