@@ -22,9 +22,28 @@ from rekuest.structures.registry import (
 
 
 def convert_child_to_childport(
-    cls, registry: StructureRegistry, nullable=False, is_return=False
+    cls,
+    registry: StructureRegistry,
+    nullable=False,
+    is_return=False,
+    annotations=None,
 ) -> Tuple[ChildPortInput, WidgetInput, Callable]:
 
+    if hasattr(cls, "__name__") and cls.__name__ == "Annotated":
+        real_type = cls.__args__[0]
+
+        annotations = [
+            registry.get_converter_for_annotation(i.__class__)(i)
+            for i in cls.__metadata__
+        ]
+
+        return convert_child_to_childport(
+            real_type,
+            registry,
+            nullable=nullable,
+            annotations=annotations,
+        )
+
     if cls.__module__ == "typing":
 
         if hasattr(cls, "_name"):
@@ -39,6 +58,7 @@ def convert_child_to_childport(
                         kind=PortKindInput.LIST,
                         child=child,
                         nullable=nullable,
+                        annotations=annotations,
                     ),
                     insidewidget,
                     lambda default: [nested_converter(ndefault) for ndefault in default]
@@ -55,6 +75,7 @@ def convert_child_to_childport(
                         kind=PortKindInput.DICT,
                         child=child,
                         nullable=nullable,
+                        annotations=annotations,
                     ),
                     insidewidget,
                     lambda default: {
@@ -78,6 +99,7 @@ def convert_child_to_childport(
             t = ChildPortInput(
                 kind=PortKindInput.BOOL,
                 nullable=nullable,
+                annotations=annotations,
             )  # catch bool is subclass of int
             return t, None, str
 
@@ -86,6 +108,7 @@ def convert_child_to_childport(
                 ChildPortInput(
                     kind=PortKindInput.INT,
                     nullable=nullable,
+                    annotations=annotations,
                 ),
                 None,
                 int,
@@ -95,6 +118,7 @@ def convert_child_to_childport(
                 ChildPortInput(
                     kind=PortKindInput.STRING,
                     nullable=nullable,
+                    annotations=annotations,
                 ),
                 None,
                 str,
@@ -113,6 +137,7 @@ def convert_child_to_childport(
             kind=PortKindInput.STRUCTURE,
             identifier=identifier,
             nullable=nullable,
+            annotations=annotations,
         ),
         widget,
         default_converter,
@@ -125,6 +150,7 @@ def convert_argument_to_port(
     registry: StructureRegistry,
     widget=None,
     default=None,
+    description=None,
     nullable=False,
     annotations=[],
 ) -> ArgPortInput:
@@ -165,6 +191,7 @@ def convert_argument_to_port(
                     default=[converter(item) for item in default] if default else None,
                     nullable=nullable,
                     annotations=annotations,
+                    description=description,
                 )
 
             if cls._name == "Dict":
@@ -176,9 +203,12 @@ def convert_argument_to_port(
                     widget=widget,
                     key=key,
                     child=child.dict(exclude={"key"}),
-                    default={key: converter(item) for key, item in default.items()},
+                    default={key: converter(item) for key, item in default.items()}
+                    if default
+                    else None,
                     nullable=nullable,
                     annotations=annotations,
+                    description=description,
                 )
 
             if cls._name == "Union":
@@ -205,6 +235,7 @@ def convert_argument_to_port(
                 default=default,
                 nullable=nullable,
                 annotations=annotations,
+                description=description,
             )  # catch bool is subclass of int
             return t
 
@@ -220,6 +251,7 @@ def convert_argument_to_port(
                 default=default,
                 nullable=nullable,
                 annotations=annotations,
+                description=description,
             )
 
         if (
@@ -234,6 +266,7 @@ def convert_argument_to_port(
                 default=default,
                 nullable=nullable,
                 annotations=annotations,
+                description=description,
             )
 
         if (
@@ -248,6 +281,7 @@ def convert_argument_to_port(
                 default=default,
                 nullable=nullable,
                 annotations=annotations,
+                description=description,
             )
 
     identifier = registry.get_identifier_for_structure(cls)
@@ -262,11 +296,17 @@ def convert_argument_to_port(
         default=default_converter(default) if default else None,
         nullable=nullable,
         annotations=annotations,
+        description=description,
     )
 
 
 def convert_return_to_returnport(
-    cls, key: str, registry: StructureRegistry, widget=None, nullable=False
+    cls,
+    key: str,
+    registry: StructureRegistry,
+    description=None,
+    widget=None,
+    nullable=False,
 ) -> ReturnPortInput:
     """
     Convert a class to an ArgPort
@@ -286,6 +326,7 @@ def convert_return_to_returnport(
                     key=key,
                     child=child.dict(exclude={"key"}),
                     nullable=nullable,
+                    description=description,
                 )
 
             if cls._name == "Dict":
@@ -298,6 +339,7 @@ def convert_return_to_returnport(
                     key=key,
                     child=child.dict(exclude={"key"}),
                     nullable=nullable,
+                    description=description,
                 )
 
         if hasattr(cls, "__args__"):
@@ -309,24 +351,33 @@ def convert_return_to_returnport(
     if inspect.isclass(cls):
         # Generic Cases
 
-        if issubclass(cls, bool):
+        if not issubclass(cls, Enum) and issubclass(cls, bool):
             return ReturnPortInput(
-                kind=PortKindInput.BOOL, key=key, nullable=nullable
-            )  # catch bool is subclass of int
-        if issubclass(cls, Enum):
-            return ReturnPortInput(
-                kind=PortKindInput.ENUM,
+                kind=PortKindInput.BOOL,
                 key=key,
-                options={key: value._value_ for key, value in cls.__members__.items()},
                 nullable=nullable,
-            )
-        if issubclass(cls, int):
-            return ReturnPortInput(kind=PortKindInput.INT, key=key, nullable=nullable)
-        if issubclass(cls, float):
-            return ReturnPortInput(kind=PortKindInput.FLOAT, key=key, nullable=nullable)
-        if issubclass(cls, str):
+                description=description,
+            )  # catch bool is subclass of int
+        if not issubclass(cls, Enum) and issubclass(cls, int):
             return ReturnPortInput(
-                kind=PortKindInput.STRING, key=key, nullable=nullable
+                kind=PortKindInput.INT,
+                key=key,
+                nullable=nullable,
+                description=description,
+            )
+        if not issubclass(cls, Enum) and issubclass(cls, float):
+            return ReturnPortInput(
+                kind=PortKindInput.FLOAT,
+                key=key,
+                nullable=nullable,
+                description=description,
+            )
+        if not issubclass(cls, Enum) and issubclass(cls, str):
+            return ReturnPortInput(
+                kind=PortKindInput.STRING,
+                key=key,
+                nullable=nullable,
+                description=description,
             )
 
     identifier = registry.get_identifier_for_structure(cls)
@@ -338,27 +389,31 @@ def convert_return_to_returnport(
         key=key,
         widget=widget,
         nullable=nullable,
+        description=None,
     )
 
 
 def prepare_definition(
     function: Callable,
-    package=None,
+    structure_registry: StructureRegistry,
     interface=None,
     widgets={},
     allow_empty_doc=False,
     interfaces=[],
-    structure_registry: StructureRegistry = None,
     omitfirst=None,
     omitlast=None,
     omitkeys=[],
 ) -> DefinitionInput:
     """Define
 
-    Define a functions in the context of arnheim and
-    return it as a Node. Attention this node is not yet
-    hosted on Arkitekt (doesn't have an id). So make sure
-    to save this node before calling it anywhere
+    Define a callable (async function, sync function, async generator, async
+    generator) in the context of arkitekt and
+    return its definition(input).
+
+    Attention this definition is not yet registered in the
+    arkitekt registry. This is done by the create_template function ( which will validate the definition with your local arkitekt instance
+    and raise an error if the definition is not compatible with your arkitekt version)
+
 
     Args:
         function (): The function you want to define
@@ -376,8 +431,34 @@ def prepare_definition(
     args: List[ArgPortInput] = []
     returns: List[ReturnPortInput] = []
 
+    # Docstring Parser to help with descriptions
+    docstring = parse(function.__doc__)
+    if docstring.long_description is None:
+        assert (
+            allow_empty_doc is not False
+        ), f"We don't allow empty documentation for function {function.__name__}. Please Provide"
+
     function_ins_annotation = sig.parameters
 
+    doc_param_map = {param.arg_name: param.description for param in docstring.params}
+
+    # TODO: Update with documentatoin.... (Set description for portexample)
+
+    doc_returns_map = {
+        f"return{index}": param.description
+        for index, param in enumerate(docstring.many_returns)
+    }
+
+    for port in args:
+        if port.key in doc_param_map:
+            updates = doc_param_map[port.key]
+            port.description = updates["description"] or port.description
+
+    for port in returns:
+        if port.key in doc_returns_map:
+            updates = doc_returns_map[port.key]
+            port.description = updates["description"] or port.description
+
     for index, (key, value) in enumerate(function_ins_annotation.items()):
 
         # We can skip arguments if the builder is going to provide additional arguments
@@ -401,6 +482,7 @@ def prepare_definition(
                     default=value.default
                     if value.default != inspect.Parameter.empty
                     else None,
+                    description=doc_param_map.get(key, None),
                 )
             )
         except Exception as e:
@@ -418,7 +500,11 @@ def prepare_definition(
                     widget = widgets.get(f"return{index}", None)
                     returns.append(
                         convert_return_to_returnport(
-                            cls, f"return{index}", structure_registry
+                            cls,
+                            f"return{index}",
+                            structure_registry,
+                            description=doc_returns_map.get(f"return{index}", None),
+                            widget=widget,
                         )
                     )
             except Exception as e:
@@ -458,45 +544,16 @@ def prepare_definition(
 
     # Documentation Parsing
 
-    # Docstring Parser to help with descriptions
-    docstring = parse(function.__doc__)
-    if docstring.long_description is None:
-        assert (
-            allow_empty_doc is not False
-        ), f"We don't allow empty documentation for function {function.__name__}. Please Provide"
-
     name = docstring.short_description or function.__name__
     interface = interface or inflection.underscore(
         function.__name__
     )  # convert this to camelcase
     description = docstring.long_description or "No Description"
 
-    doc_param_map = {
-        param.arg_name: {"description": param.description} for param in docstring.params
-    }
-
-    # TODO: Update with documentatoin.... (Set description for portexample)
-
-    doc_returns_map = {
-        f"return{index}": {"description": param.description, "label": param.return_name}
-        for index, param in enumerate(docstring.many_returns)
-    }
-
-    for port in args:
-        if port.key in doc_param_map:
-            updates = doc_param_map[port.key]
-            port.description = updates["description"] or port.description
-
-    for port in returns:
-        if port.key in doc_returns_map:
-            updates = doc_returns_map[port.key]
-            port.description = updates["description"] or port.description
-
     x = DefinitionInput(
         **{
             "name": name,
             "interface": interface,
-            "package": package,
             "description": description,
             "args": args,
             "returns": returns,
