@@ -80,11 +80,6 @@ class DefinitionRegistry(KoiledModel):
     ):
         self.defined_nodes.append((definition, actorBuilder, params))
 
-    def register_actor_with_template(
-        self, actorBuilder: Callable, q_string: QString, **params
-    ):  # Query Path
-        self.templated_nodes.append((q_string, actorBuilder, params))
-
     def register(
         self,
         function_or_actor,
@@ -139,7 +134,6 @@ class DefinitionRegistry(KoiledModel):
             definition = builder.define(
                 function=function_or_actor,
                 widgets=widgets,
-                package=package,
                 interface=interface,
                 interfaces=interfaces,
                 structure_registry=structure_registry,
@@ -147,37 +141,6 @@ class DefinitionRegistry(KoiledModel):
 
         self.register_actor_with_defintion(actorBuilder, definition, **actorparams)
 
-    def template(
-        self,
-        function,
-        qstring: QString,
-        builder: ActorBuilder = None,
-        on_provide=None,
-        on_unprovide=None,
-        structure_registry: StructureRegistry = None,
-        **actorparams,
-    ):
-        structure_registry = (
-            structure_registry
-            or self.structure_registry
-            or get_current_structure_registry()
-        )
-
-        if builder:
-            assert hasattr(builder, "actify"), "Build needs to provide actify attr"
-            assert hasattr(builder, "define"), "Builder needs to provide define attr"
-        else:
-            builder = self.defaultActorBuilder
-
-        actorBuilder = actify(
-            function,
-            on_provide=on_provide,
-            on_unprovide=on_unprovide,
-            structure_registry=structure_registry**actorparams,
-        )
-
-        self.register_actor_with_template(actorBuilder, qstring, **actorparams)
-
     async def __aenter__(self):
         self.structure_registry = (
             self.structure_registry or get_current_structure_registry()
@@ -186,7 +149,6 @@ class DefinitionRegistry(KoiledModel):
         return self
 
     def dump(self):
-        print(self.defined_nodes)
         return {
             "definitions": [
                 json.loads(x[0].json(exclude_none=True, exclude_unset=True))
