@@ -42,6 +42,7 @@ class Assignation(UpdatableModel):
     log: Optional[bool]
     status: Optional[AssignationStatus]
     message: Optional[str]
+    user: Optional[str]
 
 
 class Unassignation(UpdatableModel):
@@ -51,6 +52,7 @@ class Unassignation(UpdatableModel):
 
 class Provision(UpdatableModel):
     provision: str
+    guardian: str
     template: Optional[str]
     status: Optional[ProvisionStatus]
 
