@@ -10,12 +10,11 @@ class BasePostman(KoiledModel):
     """Postman
 
 
-    Postmans are the the messengers of the arkitekt platform, they are taking care
-    of the communication between your app and the arkitekt-server.
-
-    needs to implement:
-        broadcast: On assignation Update or on reservation update (non updated fields are none)
-
+    Postmans are the schedulers of the arkitekt platform, they are taking care
+    of the communication between your app and the arkitekt-server. And
+    provide abstractions to map the asynchornous message-based nature of the arkitekt-server to
+    the (a)sync nature of your app. It maps assignations to functions or generators
+    depending on the definition, to mimic an actor-like behaviour.
 
     """
 
